@@ -26,20 +26,14 @@ Attempts to follow the SMTP server RFCs.
 
 from __future__ import absolute_import
 
-import gevent
-from gevent.server import StreamServer
-from dns import reversename
-from dns.resolver import NXDOMAIN
-
-from slimta import logging
 from slimta.envelope import Envelope
 from slimta.smtp.server import Server
-from slimta.smtp.reply import unknown_command, bad_sequence
+from slimta.smtp.reply import Reply
 from slimta.smtp import ConnectionLost, MessageTooBig
 from slimta.queue import QueueError
 from slimta.relay import RelayError
-from slimta.util import dns_resolver
 from slimta.util.ptrlookup import PtrLookup
+from slimta.util import validate_tls
 from . import EdgeServer
 
 __all__ = ['SmtpEdge', 'SmtpValidators']
@@ -50,7 +44,11 @@ class SmtpValidators(object):
 
     Sub-classes may implement some or all of the following functions. Leaving
     the `reply` argument untouched will return the default, successful reply
-    from the command.
+    from the command. Setting the response code to ``421`` or ``221`` will
+    close the connection.
+
+    .. _RFC 2821 4.2: https://tools.ietf.org/html/rfc2821#section-4.2
+    .. seealso:: `RFC 2821 4.2`_
 
     - ``handle_banner(reply, address)``: Validate connecting address before
       sending the SMTP banner.
@@ -60,9 +58,12 @@ class SmtpValidators(object):
       a :class:`~pysasl.AuthenticationCredentials` object.
     - ``handle_mail(reply, sender, params)``: Validate the sender address.
     - ``handle_rcpt(reply, recipient, params)``: Validate one recipient
-                                                 address.
+      address.
     - ``handle_data(reply)``: Any remaining validation before receiving data.
     - ``handle_have_data(reply, data)``: Validate the received message data.
+    - ``handle_queued(reply, results)``: Once the message has been queued,
+      modify the returned |Reply| using the ``results`` from calling
+      :meth:`~slimta.queue.Queue.enqueue`.
     - ``handle_rset(reply)``: Called before replying to an RSET command.
     - ``handle_tls()``: Called after a successful TLS handshake. This may be at
       the beginning of the session or after a `STARTTLS` command.
@@ -183,13 +184,15 @@ class SmtpSession(object):
 
         results = self.handoff(self.envelope)
         if isinstance(results[0][1], QueueError):
-            reply.code = '550'
-            reply.message = '5.6.0 Error queuing message'
+            default_reply = Reply('451', '4.3.0 Error queuing message')
+            queue_reply = getattr(results[0][1], 'reply', default_reply)
+            reply.copy(queue_reply)
         elif isinstance(results[0][1], RelayError):
             relay_reply = results[0][1].reply
             reply.copy(relay_reply)
         else:
             reply.message = '2.6.0 Message accepted for delivery'
+        self._call_validator('queued', reply, results)
 
         self.envelope = None
 
@@ -234,7 +237,7 @@ class SmtpEdge(EdgeServer):
         self.data_timeout = data_timeout
         self.validator_class = validator_class
         self.auth = auth
-        self.tls = tls
+        self.tls = validate_tls(tls)
         self.tls_immediately = tls_immediately
 
     def handle(self, socket, address):
