@@ -37,6 +37,7 @@ import gevent
 from slimta import logging
 from slimta.smtp.reply import Reply
 from slimta.http import get_connection
+from slimta.util import validate_tls
 from slimta.util.pycompat import urlparse
 from . import PermanentRelayError, TransientRelayError
 from .pool import RelayPool, RelayPoolClient
@@ -173,8 +174,8 @@ class HttpRelay(RelayPool):
                       to the destination. If this limit is reached and no
                       connections are idle, new attempts will block.
     :param tls: Dictionary of TLS settings passed directly as keyword arguments
-                to :class:`gevent.ssl.SSLSocket`. This parameter is optional
-                unless ``https:`` is given in ``url``.
+                to :class:`gevent.ssl.SSLSocket`. ``False`` will explicitly
+                disable TLS.
     :param ehlo_as: The string to send as the EHLO string in a header. Defaults
                     to the FQDN of the system. This may also be given as a
                     function that will be executed with no arguments at the
@@ -205,7 +206,7 @@ class HttpRelay(RelayPool):
                  timeout=None, idle_timeout=None):
         super(HttpRelay, self).__init__(pool_size)
         self.url = urlparse.urlsplit(url, 'http')
-        self.tls = tls
+        self.tls = validate_tls(tls)
         self.ehlo_as = ehlo_as or getfqdn()
         self.timeout = timeout
         self.idle_timeout = idle_timeout
