@@ -14,11 +14,13 @@ class TestSmtpServer(unittest.TestCase, MoxTestBase):
         super(TestSmtpServer, self).setUp()
         self.sock = self.mox.CreateMock(SSLSocket)
         self.sock.fileno = lambda: -1
-        self.tls_args = {'server_side': True}
+        self.tls_args = {'certfile': '/dev/null', 'server_side': True}
 
     def test_starttls_extension(self):
         s = Server(None, None, tls=False)
         self.assertFalse('STARTTLS' in s.extensions)
+        s = Server(None, None, tls={}, tls_immediately=False)
+        self.assertFalse('STARTTLS' in s.extensions)
         s = Server(None, None, tls=self.tls_args, tls_immediately=False)
         self.assertTrue('STARTTLS' in s.extensions)
         s = Server(None, None, tls=self.tls_args, tls_immediately=True)
@@ -116,6 +118,30 @@ class TestSmtpServer(unittest.TestCase, MoxTestBase):
         s.handle()
         self.assertEqual('there', s.ehlo_as)
 
+    def test_ehlo_empty(self):
+        self.sock.sendall(b'220 ESMTP server\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'EHLO\r\n')
+        self.sock.sendall(b'501 5.5.4 Syntax error in parameters or arguments\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'QUIT\r\n')
+        self.sock.sendall(b'221 2.0.0 Bye\r\n')
+        self.mox.ReplayAll()
+        s = Server(self.sock, None)
+        s.handle()
+        self.assertEqual(None, s.ehlo_as)
+
+    def test_ehlo_empty_with_helo(self):
+        self.sock.sendall(b'220 ESMTP server\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'EHLO\r\n')
+        self.sock.sendall(b'501 5.5.4 Syntax error in parameters or arguments\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'HELO there\r\n')
+        self.sock.sendall(b'250 Hello there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'QUIT\r\n')
+        self.sock.sendall(b'221 2.0.0 Bye\r\n')
+        self.mox.ReplayAll()
+        s = Server(self.sock, None)
+        s.handle()
+        self.assertEqual('there', s.ehlo_as)
+
     def test_helo(self):
         self.sock.sendall(b'220 ESMTP server\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'HELO there\r\n')
@@ -127,6 +153,32 @@ class TestSmtpServer(unittest.TestCase, MoxTestBase):
         s.handle()
         self.assertEqual('there', s.ehlo_as)
 
+    def test_helo_empty(self):
+        self.sock.sendall(b'220 ESMTP server\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'HELO\r\n')
+        self.sock.sendall(b'501 5.5.4 Syntax error in parameters or arguments\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'QUIT\r\n')
+        self.sock.sendall(b'221 2.0.0 Bye\r\n')
+        self.mox.ReplayAll()
+        s = Server(self.sock, None)
+        s.handle()
+        self.assertEqual(None, s.ehlo_as)
+
+    def test_helo_empty_with_ehlo(self):
+        self.sock.sendall(b'220 ESMTP server\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'HELO\r\n')
+        self.sock.sendall(b'501 5.5.4 Syntax error in parameters or arguments\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'EHLO there\r\n')
+        self.sock.sendall(b'250-Hello there\r\n250 TEST\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'QUIT\r\n')
+        self.sock.sendall(b'221 2.0.0 Bye\r\n')
+        self.mox.ReplayAll()
+        s = Server(self.sock, None)
+        s.extensions.reset()
+        s.extensions.add('TEST')
+        s.handle()
+        self.assertEqual('there', s.ehlo_as)
+
     def test_starttls(self):
         sock = self.mox.CreateMockAnything()
         sock.fileno = lambda: -1
